@@ -1,4 +1,5 @@
 use array_map::*;
+use array_map_derive::Indexable;
 
 #[derive(Copy, Clone, Debug, PartialEq, Eq, Indexable)]
 pub enum Ten {
@@ -23,6 +24,8 @@ fn test_impls() {
   test_indexable::<Ten, { Ten::count() }>();
   test_indexable::<IndexU8<20>, 20>();
   test_indexable::<IndexU16<264>, 264>();
+  test_indexable::<Option<Ten>, { Ten::count() + 1 }>();
+  test_indexable::<Option<bool>, 3>();
 }
 
 fn test_indexable<I: Indexable, const N: usize>() {
@@ -40,3 +43,14 @@ fn test_indexable<I: Indexable, const N: usize>() {
 fn test_disabled() {
   Ten::Five.index();
 }
+
+#[test]
+#[should_panic]
+fn test_option_disabled() {
+  Some(Ten::Five).index();
+}
+
+#[test]
+fn test_option_none() {
+  assert_eq!(Option::<Ten>::None.index(), 9);
+}
